@@ -27,8 +27,8 @@ let unit = (Unit, QCheck.Print.unit)
 let bool = (Bool, QCheck.Print.bool)
 let char = (Char, QCheck.Print.char)
 let int = (Int, QCheck.Print.int)
-let int32 = (Int32, Int32.to_string)
-let int64 = (Int64, Int64.to_string)
+let int32 = (Int32, QCheck.Print.int32)
+let int64 = (Int64, QCheck.Print.int64)
 let float = (Float, QCheck.Print.float)
 let string = (String, QCheck.Print.string)
 let bytes = (Bytes, QCheck.Print.bytes)
