@@ -2,7 +2,7 @@
 (*                      Tests of In_channels                              *)
 (* ********************************************************************** *)
 
-module IC_thread = Lin_thread.Make(Lin_tests_spec_io.ICConf) [@@alert "-experimental"]
+module IC_thread = Lin_thread.Make(Lin_tests_spec_io.ICConf)
 
 let _ =
   QCheck_base_runner.run_tests_main [
